@@ -13,7 +13,7 @@ def generate_ascii_v(inputfile,outputfile,color=0,kernel=7,density=0.3,fancy=Fal
 
     ret, frame = vid.read()
     
-    fancy_dir = './fancy'
+    fancy_dir = '/fancy'
     fancy_num = len([name for name in os.listdir(fancy_dir) if os.path.isfile(os.path.join(fancy_dir, name))])
     #print(fancy_num)
     
@@ -75,7 +75,7 @@ def generate_ascii_v(inputfile,outputfile,color=0,kernel=7,density=0.3,fancy=Fal
                 if(fancy):
                     avg_c = np.mean(np.mean(img_fancy[i*kernel:i*kernel+kernel,j*kernel:j*kernel+kernel],axis=0),axis=0)
                 else:
-                    avg_c = np.mean(np.mean(img_c[i*kernel:i*kernel+kernel,j*kernel:j*kernel+kernel],axis=0),axis=0)
+                    avg_c = np.mean(np.mean(frame[i*kernel:i*kernel+kernel,j*kernel:j*kernel+kernel],axis=0),axis=0)
             
                 if color==0:
                     avg_c = (255,255,255)
